'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _cliEngineHeroku = require('cli-engine-heroku');

var _child_process = require('child_process');

var _nodeFetch = require('node-fetch');

var _nodeFetch2 = _interopRequireDefault(_nodeFetch);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class AutobusCommand extends _cliEngineHeroku.Command {

  async run() {
    const config = await this.heroku.get(`/apps/${this.flags.app}/config-vars`);

    const url = await (0, _nodeFetch2.default)('https://www.autobus.io/api/snapshots/latest/?token=' + config.AUTOBUS_TOKEN).then(function (res) {
      return res.text();
    });

    let cmd = `curl "${url}" | gunzip `;
    if (this.flags.nouser) {
      cmd += " | sed 's|DROP TABLE IF EXISTS `kjellk0dz_user|DROP TABLE IF EXISTS `tmp_kjellk0dz_user|g' ";
      cmd += " | sed 's|CREATE TABLE `kjellk0dz_user|CREATE TABLE `tmp_kjellk0dz_user|g' ";
      cmd += " | grep -v '`kjellk0dz_users`' | grep -v '`kjellk0dz_usermeta`' ";
    }
    if (this.flags.domain) {
      // Replace domain for certian sql rows.
      cmd += ` | sed -e 's|chef.se|${this.flags.domain}|g' `;
    }
    if (!this.flags.alldatabases) {
      // Get sql lines for the primary_app_db database.
      cmd += " | awk 'NR < 10 || /^USE `primary_app_db`/{f=1;next} /^CREATE DATABASE/{f=0} f || NR < 16' ";
    }

    (0, _child_process.execSync)(cmd, { stdio: 'inherit' });
  }
}
exports.default = AutobusCommand;
AutobusCommand.topic = 'pocus';
AutobusCommand.command = 'autobus';
AutobusCommand.description = 'Fetch latest dump from Autobus.';
AutobusCommand.flags = {
  app: _cliEngineHeroku.flags.app({ required: true }),
  nouser: _cliEngineHeroku.flags.boolean({ description: 'Exclude alla user tables.', required: false }),
  domain: _cliEngineHeroku.flags.string({ default: false, description: 'Replace wp domain to given domain value.', required: false }),
  alldatabases: _cliEngineHeroku.flags.boolean({ default: false, description: 'Get dump for all JawsDB daabases, not only wp database.', required: false })
};
AutobusCommand.args = [{ name: 'tables', optional: true }];